﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net.Http;
using System.Threading.Tasks;
using Newtonsoft.Json;

namespace zhanzhangfu
{
    /*
     1:下单:传入参数->后台请求站长付api接口,获取订单编号
     2:回调url:自己在自己网站上弄一个接口,等待订单状态回调,在站长付后台设置回调地址,订单成功支付后站长付会请求你在下单时候设置的回调url,你根据传过来的状态自己写逻辑即可
     3:查询订单状态,传入订单编号,自己主动获取订单状态
         
         */
    public class ZZFHelper
    {
        #region 字段

        /// <summary>
        /// APPKEY(自己站长付后台的)
        /// </summary>
        private static string _appKey = "xxxxxxx";

        /// <summary>
        /// APPSECRET(自己站长付后台的)
        /// </summary>
        private static string _appSecret = "xxxxxxxxxxxx";

        /// <summary>
        /// 下单请求地址
        /// </summary>
        private static string _payUrl = "https://admin.zhanzhangfu.com/order/createOrder";

        /// <summary>
        /// 查询订单地址
        /// </summary>
        private static string _selectUrl = "https://admin.zhanzhangfu.com/order/onlinePayFindResult";
        #endregion


        #region 方法

        /// <summary>
        /// 发送下单请求
        /// 描述:后台请求api,传入参数,
        /// </summary>
        /// <returns></returns>
        public static PayBack PostMessage(PayInfo data)
        {
            try
            {
                HttpClient httpClient = new HttpClient();
                httpClient.DefaultRequestHeaders.Add("Payment-Key", _appKey);
                httpClient.DefaultRequestHeaders.Add("Payment-Secret", _appSecret);
               
                var paramDate = new FormUrlEncodedContent(new Dictionary<string, string>()
                                 {
                                     {"price",data.price},
                                     {"name",data.name },
                                     {"reurl",data.reurl },
                                     {"thirduid",data.thirduid },
                                     {"remarks",data.remarks },
                                     {"other",data.other },
                                     {"callbackurl",data.callbackurl },
                                  });
                HttpResponseMessage httpResponseMessage = httpClient.PostAsync(_payUrl, paramDate).Result;
                var result = httpResponseMessage.Content.ReadAsStringAsync().Result;
                return JsonConvert.DeserializeObject<PayBack>(result);
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
            }
            return null;
        }

        /// <summary>
        /// 获取订单状态
        /// </summary>
        /// <param name="orderId">订单ID</param>
        /// <returns></returns>
        public static PayState GetPayState(string orderId)
        {
            try
            {
                HttpClient httpClient = new HttpClient();
                httpClient.DefaultRequestHeaders.Add("Payment-Key", _appKey);
                httpClient.DefaultRequestHeaders.Add("Payment-Secret", _appSecret);

                var paramDate = new FormUrlEncodedContent(new Dictionary<string, string>()
                                 {
                                     {"orderId",orderId},
                                  });
                HttpResponseMessage httpResponseMessage = httpClient.PostAsync(_selectUrl, paramDate).Result;
                var result = httpResponseMessage.Content.ReadAsStringAsync().Result;
                return JsonConvert.DeserializeObject<PayState>(result);
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
            }
            return null;
        }
        #endregion


    }
    public class PayInfo
    {
        public string price { get; set; }
        public string name { get; set; }
        public string reurl { get; set; }
        public string thirduid { get; set; }
        public string remarks { get; set; }
        public string other { get; set; }
        public string callbackurl { get; set; }
    }

    public class PayState
    {
        public string msg { get; set; }
        public string code { get; set; }
        public string state { get; set; }
    }
    public class PayBack
    {
        public string msg { get; set; }
        public string other { get; set; }
        public string code { get; set; }
        public string orderId { get; set; }
        public string price { get; set; }
        public string name { get; set; }
        public string reurl { get; set; }
        public string thirduid { get; set; }

        public string originalprice { get; set; }

        public string remarks { get; set; }
    }
    
}
